@@ -36,7 +36,9 @@ public:
         VideoId,
         Artists,
         Album,
+        AlbumId,
         IsCurrent,
+        Duration
     };
     Q_ENUM(Role);
 
